"""Predefined colors"""

# pylint: disable=fixme
# Todo: use a color library?

WHITE   = (255,255,255)
GRAY    = ( 50, 50, 50)

RED     = (255,  0,  0)
ORANGE  = (255,125,  0)
YELLOW  = (255,255,  0)
GREEN   = (  0,255,  0)
BLUE    = (  0,  0,255)
PURPLE  = (255,  0,255)

ON = WHITE
OFF = GRAY
